%% This is an example script that demonstrates how to use the Event_File_Reader_9_0.dll.


% This example creates a struct called EventRecords that has a length of the number of records in the event log file with the following fields:
% EventNumber (double)
% EventType (string)  TimeStamp (string), 
% TimeMsFromMidnight (double)
% TimeSource (string)
% Details (string)

clear; clc;
% User settings
eventFileReaderDll =  ''; % set FULL PATH of dll including full name
filesetType = 'Flat'; %either 'Block' for block type data of 'Flat' for flat type data
folderName = ''; %folder containing file(s) you wish to load - full path

%% Set up files to load 
% EVENT000.DF1 may be included among the files containing events but it is
% not required. You can assemble your cell array of file names in listOfFilesToLoad
% with your own custom code, but you must afterwards run the following segment ("change this to a .NET array") 
if strcmp(filesetType, 'Block')
    IncludeEventFile = 1; %if to include event file
    minFileIndex = 0; % the number of the first file to load (e.g. for NEUR0003, set minFileIndex = 3);
    maxFileIndex = 33;% the number of the last file to load 
    count = 1;
    if (IncludeEventFile)
        listOfFilesToLoad = cell(maxFileIndex - minFileIndex + 2, 1);
        listOfFilesToLoad{1} = fullfile(folderName, 'EVENT000.DF1'); % set event file to first file
        count = count + 1;
    end

    filePrefix = 'NEUR'; % 4 letter prefix of file (e.g. for NEUR0000 it would be NEUR)
    for fileIdx = minFileIndex:maxFileIndex
        indexStr = num2str(fileIdx,'%04.f');
        listOfFilesToLoad{count} = fullfile(folderName, strcat(filePrefix, indexStr, '.DF1'));
        count = count + 1;
    end
elseif strcmp(filesetType, 'Flat')
    EventFileName = 'EVENTLOG.NLE'; %include full file path of folder
    IncludeEventFile = false;
    listOfFilesToLoad{1} = fullfile(folderName, EventFileName);
end
numberOfFiles = length(listOfFilesToLoad);

%% Load in assembly
asminfo = NET.addAssembly(eventFileReaderDll); % loads in .NET dll
c = Event_File_Reader_9_0.EFRMatlabFunctions();
c.Initialize();
tic
%% For each file, call dll to extract/interpret events of a single file
EventRecordsStructs = cell(1, numberOfFiles);

for i = 1:numberOfFiles
    % change this to a .NET array
    fileNames = NET.createArray('System.String',1);
    fileNames.Set(0, listOfFilesToLoad{i});
    fprintf('Extracting events from file %s...\n', listOfFilesToLoad{i});
    errorCode = c.LoadFiles(fileNames);% load eventlog file, returns an int as error code
    % check if executed successfully
    if (errorCode ~= 0) % if LoadFile returned an error, display appropriate error message
        errorStr = c.GetErrorAsString(errorCode);
        error(char(errorStr));
        return;
    end
    % get number of records
    numberOfRecords = c.GetNumberOfRecords(); % get number of records in event log
    fprintf('The number of records is: %d\n',  numberOfRecords);
    %extract records
    EventRecordsStructs{i} = ExtractRecordsToStruct( c, numberOfRecords );
end

% if included events file, sort events chronologically
if IncludeEventFile
    eventRecords = EventRecordsStructs{1};
    dataEventRecords = EventRecordsStructs(2:end);
    sortedEventRecords = SortEvents(eventRecords, dataEventRecords);
else    
    sortedEventRecords = cat(2, EventRecordsStructs{:}); %no re-ordering to do, can simply flatten file set
end

EventRecords = FixEventNumbering(sortedEventRecords);

for i =2:length(EventRecords)
    if (strcmp(EventRecords(i).EventType, 'Continuation record')) %change continuation record to continued
        EventRecords(i).EventType = '...Continued';
    end

    if (strcmp(EventRecords(i).EventType, '...Continued')) %fix numbering
        EventRecords(i).EventNumber = EventRecords(i-1).EventNumber + 0.1;
    else
        EventRecords(i).EventNumber = floor(EventRecords(i-1).EventNumber) + 1;
    end
end


