function [ eventsListOrdered ] = SortEvents( eventRecords, dataEventRecords )
    %%  Put events in chronological order (only required if event file is included)
    startRecordingCount = 0;
    stoppedRecordingCount = 0;
    msInDay = 86400000;

    %get timestamps of each start recording
    for i = 1:length(eventRecords) 
        if strcmp(eventRecords(i).Details, 'Started recording') && strcmp(eventRecords(i).EventType, 'Mode change')
            startRecordingCount = startRecordingCount + 1;
            recordingStartTimestamp(startRecordingCount) = eventRecords(i).TimeMsFromMidnight;
            startRecordingIndex(startRecordingCount) = i;
            if i < length(eventRecords) - 1
                recordingStoppedTimestamp(startRecordingCount) = eventRecords(i+1).TimeMsFromMidnight;
            else
                recordingStoppedTimestamp(startRecordingCount) = msInDay;
            end
        end


    end
    %%%%%%% EDIT PART BELOW
    % find which files belong to each recording
    firstFileInRecording = 1;
    numRecordings = length(recordingStartTimestamp);
    dataFileStartRecordingTimestamps = [];
    recordingFileIndices = cell(1, numRecordings);
    for recordingIdx = 1:numRecordings
        recordingCrossesMidnight = false;
        fileListInRecording = [];
        for fileIdx = firstFileInRecording:length(dataEventRecords)
            if dataEventRecords{fileIdx}(1).TimeMsFromMidnight == recordingStartTimestamp(recordingIdx) %if first timestamp in file matches start recording timestamp
                fileListInRecording = [fileListInRecording fileIdx];
                dataFileStartRecordingTimestamps = [dataFileStartRecordingTimestamps dataEventRecords{fileIdx}(1).TimeMsFromMidnight];
            else
                if fileIdx > 1 %check if file crosses midnight
                    if (dataEventRecords{fileIdx}(1).TimeMsFromMidnight < ... 
                        dataEventRecords{fileIdx-1}(1).TimeMsFromMidnight) && ...
                        ~strcmp(dataEventRecords{fileIdx}(1).EventType, 'Event logging error')
                        recordingCrossesMidnight = true;

                    end
                end
                tempFileStartTimestamp = dataEventRecords{fileIdx}(1).TimeMsFromMidnight;
                tempRecordingStoppedTimestamp = recordingStoppedTimestamp(recordingIdx);
                if recordingCrossesMidnight %not tested
                    tempFileStartTimestamp = tempFileStartTimestamp + msInDay;
                    tempRecordingStoppedTimestamp = tempRecordingStoppedTimestamp + msInDay;
                end
                if tempFileStartTimestamp < tempRecordingStoppedTimestamp
                    fileListInRecording = [fileListInRecording fileIdx];
                    firstFileInRecording = fileIdx + 1;
                end
            end
        end        
    
        recordingFileIndices{recordingIdx} = fileListInRecording;        
    end

    %remove doubled started and stopped recording events (since start recording events
    %appear both in event and data files)
    for fileIdx = 1:length(dataEventRecords)
        thisFileEvents = dataEventRecords{fileIdx};
        for eventIdx = 1:length(thisFileEvents)
            if (strcmp(thisFileEvents(eventIdx).Details,'Started recording') || ... 
               strcmp(thisFileEvents(eventIdx).Details,'Stopped recording')) ...  
                && strcmp(thisFileEvents(eventIdx).EventType, 'Mode change') ...
                    dataEventRecords{fileIdx}(eventIdx) = [];
            end
        end
    end

    eventIdx = 1;
    eventsListOrdered = [];
    for recordingIdx = 1:numRecordings
        eventsListOrdered = [eventsListOrdered eventRecords(eventIdx:startRecordingIndex(recordingIdx))]; %add events in event file before recording start
        eventIdx = startRecordingIndex(recordingIdx) + 1;%skip stopped recording event in event file to avoid doubles
        for fileIdx = recordingFileIndices{recordingIdx} %add all events from files in recording
            eventsListOrdered = [eventsListOrdered dataEventRecords{fileIdx}];
        end
    end

    if eventIdx < length(eventRecords) %if there are more event records in event file after last data file
        eventsListOrdered = [eventsListOrdered eventRecords(eventIdx:end)];
    end



end
    


